==> flush_single_image-8.x-2.1.tar.gz: flush_single_image/src/FlushSingleImage.php <==
<?php

namespace Drupal\flush_single_image;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\File\FileSystemInterface;
use Drupal\Core\StreamWrapper\StreamWrapperManager;

/**
 * Class FlushSingleImage.
 */
class FlushSingleImage implements FlushSingleImageInterface {

  /**
   * Drupal\Core\Entity\EntityTypeManager definition.
   *
   * @var \Drupal\Core\Entity\EntityTypeManager
   */
  protected $entityTypeManager;

  /**
   * Drupal\Core\File\FileSystem definition.
   *
   * @var \Drupal\Core\File\FileSystem
   */
  protected $fileSystem;

  /**
   * Constructs a new FlushSingleImage object.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager, FileSystemInterface $file_system) {
    $this->entityTypeManager = $entity_type_manager;
    $this->fileSystem = $file_system;
  }

  /**
   * {inheritdoc}
   */
  public function flush($path) {
    $style_paths = $this->getStylePaths($path);
    foreach ($style_paths as $style_path) {
      $this->fileSystem->unlink($style_path);
    }

    return $style_paths;
  }

  /**
   * {inheritdoc}
   */
  public function getStylePaths($path) {
    $path = $this->buildUri($path);
    $styles = $this->entityTypeManager->getStorage('image_style')
      ->loadMultiple();
    $style_paths = [];

    foreach ($styles as $style) {
      $style_path = $style->buildUri($path);
      if (is_file($style_path) && file_exists($style_path)) {
        $style_paths[] = $style_path;
      }
      $path_parts = pathinfo($style_path);
      $style_path_webp = $path_parts['dirname'] . '/' . $path_parts['filename'] . '.webp';
      if (is_file($style_path_webp) && file_exists($style_path_webp)) {
        $style_paths[] = $style_path_webp;
      }
    }

    return $style_paths;
  }

  /**
   * Build a URI for a given path if it's missing the scheme.
   */
  protected function buildUri($path) {
    if (!StreamWrapperManager::getScheme($path)) {
      $default_scheme = \Drupal::config('system.file')->get('default_scheme');
      $path = $default_scheme . '://' . preg_replace('/^\//' ,'', $path);
    }
    return $path;
  }

}

==> flush_single_image-8.x-2.2.tar.gz: flush_single_image/src/FlushSingleImage.php <==
<?php

namespace Drupal\flush_single_image;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\File\FileSystemInterface;
use Drupal\Core\StreamWrapper\StreamWrapperManager;
use Drupal\image\Entity\ImageStyle;

/**
 * Class FlushSingleImage.
 */
class FlushSingleImage implements FlushSingleImageInterface {

  const ACTION_UNLINK = 1;

  const ACTION_REGENERATE = 2;

  /**
   * Drupal\Core\Entity\EntityTypeManager definition.
   *
   * @var \Drupal\Core\Entity\EntityTypeManager
   */
  protected $entityTypeManager;

  /**
   * Drupal\Core\File\FileSystem definition.
   *
   * @var \Drupal\Core\File\FileSystem
   */
  protected $fileSystem;

  /**
   * Constructs a new FlushSingleImage object.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager, FileSystemInterface $file_system) {
    $this->entityTypeManager = $entity_type_manager;
    $this->fileSystem = $file_system;
  }

  /**
   * {inheritdoc}
   */
  public function flush($path, $action = self::ACTION_UNLINK) {
    if (!in_array($action, [self::ACTION_UNLINK, self::ACTION_REGENERATE])) {
      throw new \InvalidArgumentException("The argument \$action must be either " . get_class($this) . "::ACTION_UNLINK or " . get_class($this) . "::ACTION_REGENERATE");
    }

    $style_paths = $this->getStylePaths($path);
    foreach ($style_paths as $style_id => $style_path) {
      $this->fileSystem->unlink($style_path);
      if ($action == self::ACTION_UNLINK) {
        $this->fileSystem->unlink($style_path);
      }
      elseif ($action == self::ACTION_REGENERATE) {
        $imageStyle = ImageStyle::load($style_id);
        $imageStyle->createDerivative($path, $style_path);
      }
    }

    return $style_paths;
  }

  /**
   * {inheritdoc}
   */
  public function getStylePaths($path) {
    $path = $this->buildUri($path);
    $styles = $this->entityTypeManager->getStorage('image_style')
      ->loadMultiple();

    $style_paths = [];
    foreach ($styles as $style) {
      /** @var \Drupal\image\Entity\ImageStyle  $style */
      $style_path = $style->buildUri($path);
      if (is_file($style_path) && file_exists($style_path)) {
        $style_paths[$style->id()] = $style_path;
      }
      $path_parts = pathinfo($style_path);
      $style_path_webp = $path_parts['dirname'] . '/' . $path_parts['filename'] . '.webp';
      if (is_file($style_path_webp) && file_exists($style_path_webp)) {
        $style_paths[$style->id()] = $style_path_webp;
      }
    }

    return $style_paths;
  }

  /**
   * Build a URI for a given path if it's missing the scheme.
   */
  protected function buildUri($path) {
    if (!StreamWrapperManager::getScheme($path)) {
      $default_scheme = \Drupal::config('system.file')->get('default_scheme');
      $path = $default_scheme . '://' . preg_replace('/^\//', '', $path);
    }
    return $path;
  }

}
